@@ -5,6 +5,7 @@ import botocore.exceptions
 import boto3.dynamodb.conditions
 import circuitbreaker
 import concurrent.futures
+import hashlib
 
 
 class ItemKey:
@@ -140,17 +141,23 @@ class DB:
         kwargs = {"Item": item}
         if expect_if_item_exists:
             statements = []
+            expression_names = {}
             expression_values = {}
             for name, value in expect_if_item_exists.items():
-                statements.append(f"{name}=:{name}")
-                expression_values[f":{name}"] = value
+                hashed_name = self._hash_name(name)
+                statements.append(f"#{hashed_name}=:{hashed_name}")
+                expression_names[f"#{hashed_name}"] = name
+                expression_values[f":{hashed_name}"] = value
             condition_expression = " AND ".join(statements)
             # or item does not exist
-            condition_expression = f"({condition_expression}) OR {key.name}<>:{key.name}"
-            expression_values[f":{key.name}"] = key.value
+            hashed_key_name = self._hash_name(key.name)
+            condition_expression = f"({condition_expression}) OR #{hashed_key_name}<>:{hashed_key_name}"
+            expression_names[f"#{hashed_key_name}"] = key.name
+            expression_values[f":{hashed_key_name}"] = key.value
             kwargs = {
                 **kwargs,
                 "ConditionExpression": condition_expression,
+                "ExpressionAttributeNames": expression_names,
                 "ExpressionAttributeValues": expression_values,
             }
         try:
@@ -166,38 +173,52 @@ class DB:
 
         def build_expression():  # apply diff
             statements = []
+            names = {}
             values = {}
 
-            for name, attribute in item.items():
+            for name, value in item.items():
+                hashed_name = self._hash_name(name)
+
+                if type(value) is dict and name in old_item:
+                    for sub_name, sub_value in value.items():
+                        hashed_sub_name = self._hash_name(sub_name)
+                        if sub_name not in old_item[name] or old_item[name][sub_name] != sub_value:
+                            statements.append(f"SET #{hashed_name}.#{hashed_sub_name}=:{hashed_name + hashed_sub_name}")
+                            names[f"#{hashed_sub_name}"] = sub_name
+                            values[f":{hashed_name + hashed_sub_name}"] = sub_value
 
-                if type(attribute) is dict and name in old_item:
-                    for sub_name, sub_attribute in attribute.items():
-                        if sub_name not in old_item[name] or old_item[name][sub_name] != sub_attribute:
-                            statements.append(f"SET {name}.{sub_name}=:{name + sub_name}")
-                            values[f":{name + sub_name}"] = sub_attribute
                     for old_sub_name in old_item.get(name, {}):
-                        if old_sub_name not in attribute:
-                            statements.append(f"DELETE {name}.{old_sub_name}")
+                        if old_sub_name not in value:
+                            hashed_old_sub_name = self._hash_name(old_sub_name)
+                            statements.append(f"DELETE #{hashed_name}.#{hashed_old_sub_name}")
+                            names[f"#{hashed_old_sub_name}"] = old_sub_name
 
-                elif name not in old_item or old_item[name] != attribute:
-                    statements.append(f"SET {name}=:{name}")
-                    values[f":{name}"] = attribute
+                elif name not in old_item or old_item[name] != value:
+                    statements.append(f"SET #{hashed_name}=:{hashed_name}")
+                    names[f"#{hashed_name}"] = name
+                    values[f":{hashed_name}"] = value
 
             for old_name in old_item:
                 if old_name not in item:
-                    statements.append(f"DELETE {old_name}")
+                    hashed_old_name = self._hash_name(old_name)
+                    statements.append(f"DELETE #{hashed_old_name}")
+                    names[f"#{hashed_old_name}"] = old_name
 
-            return ", ".join(statements), values
+            return ", ".join(statements), names, values
 
-        expression, expression_values = build_expression()
+        expression, expression_names, expression_values = build_expression()
+
+        hashed_key_name = self._hash_name(key.name)
+        expression_names[f"#{hashed_key_name}"] = key.name
 
         try:
             self._table.update_item(
                 Key=key.as_dynamodb_key(),
                 UpdateExpression=expression,
+                ExpressionAttributeNames=expression_names,
                 ExpressionAttributeValues=expression_values,
                 # make sure that item is being updated, not created
-                ConditionExpression=f"attribute_exists({key.name})",
+                ConditionExpression=f"attribute_exists(#{hashed_key_name})",
             )
         except botocore.exceptions.ClientError as e:
             raise InternalError() from e
@@ -208,6 +229,10 @@ class DB:
         except botocore.exceptions.ClientError as e:
             raise InternalError() from e
 
+    @staticmethod
+    def _hash_name(name: str):
+        return str(hashlib.md5(bytes(name, "utf-8")).hexdigest())
+
 
 class DBMock:
 
